@@ -14,7 +14,7 @@ echo "Uncompressing example sources"
 gzip -dr $HOME/allegro5-examples
 
 echo Creating symbolic link to DejaVuSans.ttf
-ln -s /usr/share/fonts/truetype/ttf-dejavu/DejaVuSans.ttf $HOME/allegro5-examples/data
+ln -s /usr/share/fonts/truetype/dejavu/DejaVuSans.ttf $HOME/allegro5-examples/data
 
 #For simplicity we link against all libraries provided by Allegro here.
 #Probably no example will really need all of them. We put the linker
